"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var events_1 = require("events");
var imap_1 = __importDefault(require("imap"));
var mailparser_1 = require("mailparser");
var htmlToText = __importStar(require("html-to-text"));
/*
    Inspired by:
     * https://github.com/circuithub/mail-listener
     * https://gist.github.com/bergie/1226809
*/
var MailListener = /** @class */ (function (_super) {
    __extends(MailListener, _super);
    function MailListener(auth) {
        var _this = _super.call(this) || this;
        _this.imap = new imap_1.default({
            user: auth.user,
            password: auth.pass,
            host: auth.host,
            port: auth.port,
            tls: auth.secure
        });
        var imap = _this.imap;
        // Setup ready event
        imap.once('ready', function () {
            _this.emit('imap:connected');
            // Open the inbox
            imap.openBox('INBOX', false, function (err, box) {
                if (err)
                    return _this.emit('error', err);
                // Check for new emails
                _this.parseEmails();
                // Listen for new emails
                imap.on('mail', function (id) {
                    _this.emit('incoming', id);
                    _this.parseEmails();
                });
            });
        });
        // Handle imap events
        imap.once('error', function (err) { return _this.emit('error', err); });
        imap.once('end', function () { return _this.emit('imap:disconnected'); });
        // Connect to the server
        imap.connect();
        return _this;
    }
    MailListener.prototype.parseEmails = function () {
        var _this = this;
        // Search the inbox for new mail
        var imap = this.imap;
        imap.search(['UNSEEN'], function (err, results) {
            if (err)
                return _this.emit('error', err);
            // End if there is no new mail
            if (Array.isArray(results) && results.length === 0)
                return;
            // Fetch the new mail
            var fetch = imap.fetch(results, { bodies: '', markSeen: true });
            fetch.on('message', function (msg, id) {
                var buffer = '';
                // Handle message data
                msg.on('body', function (stream, info) {
                    stream.on('data', function (chunk) { buffer += chunk; });
                });
                // Parse message data
                msg.once('end', function () {
                    // Parse email buffer
                    mailparser_1.simpleParser(buffer, function (err, mail) {
                        if (err)
                            return _this.emit('error', err);
                        // Parse email html
                        if (mail.html) {
                            mail.html = htmlToText.fromString(mail.html);
                        }
                        // Emit mail event
                        _this.emit('mail', mail);
                    });
                });
            });
        });
    };
    MailListener.prototype.end = function () {
        this.imap.end();
    };
    return MailListener;
}(events_1.EventEmitter));
exports.default = MailListener;
//# sourceMappingURL=MailListener.js.map