/// <reference types="node" />
import { EventEmitter } from 'events';
import SMTPTransport from 'nodemailer/lib/smtp-transport';
import { ImapAuth } from './MailListener';
import { Separator, MessageDetails, Mail } from './Separator';
import { SendMailOptions, Transporter } from 'nodemailer';
interface Account {
    user: string;
    pass: string;
}
interface AuthBasics {
    account: Account;
    imap: Omit<ImapAuth, 'user' | 'pass'>;
    defaults?: SMTPTransport.Options;
}
export interface AuthWithSmtp extends AuthBasics {
    smtp: Omit<ImapAuth, 'user' | 'pass'>;
}
export interface AuthWithTransporter extends AuthBasics {
    transport: Transporter;
}
export declare type Auth = AuthWithSmtp | AuthWithTransporter;
interface SendEmailOptions extends SendMailOptions {
    to: string;
}
interface SendTextOptions extends SendEmailOptions {
    body: string;
}
declare type ReplyFunction = (options: string | SendEmailOptions) => Promise<void>;
declare interface Gators {
    on(event: 'connected', listener: () => void): this;
    on(event: 'message', listener: (details: MessageDetails, sendReply: ReplyFunction) => void): this;
    on(event: 'email', listener: (mail: Mail) => void): this;
    on(event: 'error', listener: (err: Error) => void): this;
    on(event: string, listener: Function): this;
}
declare class Gators extends EventEmitter {
    private email;
    private separators;
    static carriers: string[];
    constructor(auth: Auth, customSeparators?: Separator[]);
    connect(): void;
    private passAlongMail;
    private handleMail;
    private runSeparators;
    private constructReplyFn;
    separate(separator: Separator): this;
    send(options: SendEmailOptions): Promise<void>;
    sendText(phone: string | number, carrier: string, options: string | SendTextOptions): Promise<void>;
}
export default Gators;
